#
# spec file for package gnome-desktop
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define IS_DEFAULT_GNOME_DESKTOP 1

Name:           gnome-desktop
Version:        3.0.0
Release:        1
License:        LGPLv2.1+
Summary:        The GNOME Desktop API Library
Url:            http://www.gnome.org
Group:          System/GUI/GNOME
Source:         %{name}-%{version}.tar.bz2
Source99:       baselibs.conf
BuildRequires:  fdupes
BuildRequires:  gnome-doc-utils-devel
BuildRequires:  gobject-introspection-devel
BuildRequires:  intltool
BuildRequires:  translation-update-upstream
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gsettings-desktop-schemas)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libstartup-notification-1.0)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xrandr)
%if 0%{?BUILD_FROM_VCS}
BuildRequires:  gnome-common
BuildRequires:  gtk-doc
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package contains the desktop-wide files.

%if %IS_DEFAULT_GNOME_DESKTOP || 0%{?BUILD_FROM_VCS}

%package -n gnome-version
License:        LGPLv2.1+
Summary:        GNOME version
Group:          System/GUI/GNOME
%if %IS_DEFAULT_GNOME_DESKTOP
Obsoletes:      gnome-about < %{version}
%endif

%description -n gnome-version
This package contains information on the version of GNOME that is installed.
%endif

%package -n libgnome-desktop-3-0
License:        LGPLv2.1+
Summary:        The GNOME Desktop API Library
Group:          System/GUI/GNOME
Requires:       gsettings-desktop-schemas
Recommends:     %{name}-lang
Provides:       %{name} = %{version}
%if %IS_DEFAULT_GNOME_DESKTOP
Obsoletes:      %{name} < %{version}
%endif

%description -n libgnome-desktop-3-0
The libgnome-desktop library provides API shared by several applications
on the desktop, but that cannot live in the platform for various
reasons. There is no API or ABI guarantee, although we are doing our
best to provide stability. Documentation for the API is available with
gtk-doc.

%package -n libgnome-desktop-3-devel
License:        LGPLv2.1+
Summary:        The GNOME Desktop API Library -- Development Files
Group:          Development/Libraries/GNOME
Requires:       libgnome-desktop-3-0 = %{version}
%if %IS_DEFAULT_GNOME_DESKTOP
Provides:       %{name}-devel = %{version}
Obsoletes:      %{name}-devel < %{version}
Provides:       %{name}-doc = %{version}
Obsoletes:      %{name}-doc < %{version}
%endif

%description -n libgnome-desktop-3-devel
The libgnome-desktop library provides API shared by several applications
on the desktop, but that cannot live in the platform for various
reasons. There is no API or ABI guarantee, although we are doing our
best to provide stability. Documentation for the API is available with
gtk-doc.

%lang_package
%prep
%setup -q
translation-update-upstream

%if 0%{?BUILD_FROM_VCS}
[ -x ./autogen.sh] && NOCONFIGURE=1 ./autogen.sh
%endif

%build
%configure --with-pic\
	--disable-static\
%if ! %IS_DEFAULT_GNOME_DESKTOP
        --disable-desktop-docs \
%endif
%if 0%{?BUILD_FROM_VCS}
        --enable-gtk-doc \
%endif
        --disable-scrollkeeper \
        --with-gnome-distributor="SUSE" \
        --disable-date-in-gnome-version
make %{?_smp_mflags} V=1

%install
%makeinstall
%if 0%{?suse_version} <= 1110
%{__rm} %{buildroot}%{_datadir}/locale/ig/LC_MESSAGES/*
%endif
%if 0%{?suse_version} <= 1120
%{__rm} %{buildroot}%{_datadir}/locale/en@shaw/LC_MESSAGES/*
%endif
%if 0%{?suse_version} <= 1130
%{__rm} %{buildroot}%{_datadir}/locale/kg/LC_MESSAGES/*
%endif
%find_lang %{name}-3.0 %{?no_lang_C}
%if %IS_DEFAULT_GNOME_DESKTOP
%find_lang fdl %{?no_lang_C} %{name}-3.0.lang
%find_lang gpl %{?no_lang_C} %{name}-3.0.lang
%find_lang lgpl %{?no_lang_C} %{name}-3.0.lang
%else
%if ! 0%{?BUILD_FROM_VCS}
rm %{buildroot}%{_datadir}/gnome/gnome-version.xml
%endif
%endif
%{__rm} -vf %{buildroot}%{_libdir}/*.la
%fdupes %{buildroot}

%clean
rm -rf %{buildroot}

%post -n libgnome-desktop-3-0 -p /sbin/ldconfig

%postun -n libgnome-desktop-3-0 -p /sbin/ldconfig

%files -n libgnome-desktop-3-0
%defattr(-, root, root)
%doc AUTHORS COPYING.LIB NEWS README
%if %IS_DEFAULT_GNOME_DESKTOP
# We don't have a better location for the license help files
%dir %{_datadir}/gnome/
%dir %{_datadir}/gnome/help/
%dir %{_datadir}/gnome/help/*/
%doc %{_datadir}/gnome/help/*/C/
%dir %{_datadir}/omf/
%dir %{_datadir}/omf/*/
%doc %{_datadir}/omf/*/*-C.omf
%endif
%{_datadir}/libgnome-desktop-3.0/
%{_libdir}/libgnome-desktop-3.so.*
%{_libdir}/girepository-1.0/GnomeDesktop-3.0.typelib

%files -n libgnome-desktop-3-devel
%defattr (-, root, root)
%{_includedir}/gnome-desktop-3.0/
%{_libdir}/libgnome-desktop-3.so
%{_libdir}/pkgconfig/gnome-desktop-3.0.pc
%{_datadir}/gir-1.0/*.gir
%doc %{_datadir}/gtk-doc/html/gnome-desktop3/

%files lang -f %{name}-3.0.lang

%if %IS_DEFAULT_GNOME_DESKTOP || 0%{?BUILD_FROM_VCS}

%files -n gnome-version
%defattr (-, root, root)
%dir %{_datadir}/gnome
%{_datadir}/gnome/gnome-version.xml
%endif

%changelog
